==> medialibrary_0.6.0.orig.tar.bz2: medialibrary-0.6.0/src/utils/Directory.h <==
/*****************************************************************************
 * Media Library
 *****************************************************************************
 * Copyright (C) 2017-2019 Hugo Beauzée-Luyssen, Videolabs, VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *          Alexandre Fernandez <nerf@boboop.fr>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#pragma once

#include <string>

namespace medialibrary
{

namespace fs
{
    class IDirectory;
}

namespace utils
{

namespace fs
{

bool isDirectory( const std::string& path );
std::string toAbsolute( const std::string& path );
bool mkdir( const std::string& path );
/**
 * @brief rmdir Remove a directory and all the files it contains
 * @param path The path to remove
 *
 * This will *not* remove subdirectories
 */
bool rmdir( medialibrary::fs::IDirectory& dir );

}

}

}

==> medialibrary_0.12.3.orig.tar.bz2: medialibrary-0.12.3/src/utils/Directory.h <==
/*****************************************************************************
 * Media Library
 *****************************************************************************
 * Copyright (C) 2017-2019 Hugo Beauzée-Luyssen, Videolabs, VideoLAN
 *
 * Authors: Hugo Beauzée-Luyssen <hugo@beauzee.fr>
 *          Alexandre Fernandez <nerf@boboop.fr>
 *
 * This program is free software; you can redistribute it and/or modify it
 * under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation; either version 2.1 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program; if not, write to the Free Software Foundation,
 * Inc., 51 Franklin Street, Fifth Floor, Boston MA 02110-1301, USA.
 *****************************************************************************/

#pragma once

#include <string>

namespace medialibrary
{

namespace utils
{

namespace fs
{

bool isDirectory( const std::string& path );
std::string toAbsolute( const std::string& path );
/**
 * @brief mkdir Creates a directory including the intermediate directories if needed
 * @param path The path to the folder to create
 * @return true in case of success, false otherwise
 *
 * @warning This only supports absolute path
 */
bool mkdir( const std::string& path );
/**
 * @brief rmdir Remove a directory and all the files it contains
 * @param path The path to remove
 *
 * This will *not* remove subdirectories
 */
bool rmdir( std::string path );

}

}

}
